/*
 * ============LICENSE_START=======================================================
 * policy-endpoints
 * ================================================================================
 * Copyright (C) 2017-2018 AT&T Intellectual Property. All rights reserved.
 * Modified Copyright (C) 2018 Samsung Electronics Co., Ltd.
 * ================================================================================
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * ============LICENSE_END=========================================================
 */

package org.onap.policy.common.endpoints.event.comm.bus.internal;

import org.onap.policy.common.endpoints.event.comm.Topic;
import org.onap.policy.common.endpoints.event.comm.bus.UebTopicSink;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * This implementation publishes events for the associated UEB topic, inline with the calling
 * thread.
 */
public class InlineUebTopicSink extends InlineBusTopicSink implements UebTopicSink {

    /**
     * Logger.
     */
    private static Logger logger = LoggerFactory.getLogger(InlineUebTopicSink.class);

    /**
     * Argument-based UEB Topic Writer instantiation. BusTopicParams contains below mentioned
     * attributes.
     *
     * <p>servers              list of UEB servers available for publishing
     * topic                the topic to publish to
     * apiKey               the api key (optional)
     * apiSecret            the api secret (optional)
     * partitionId          the partition key (optional, autogenerated if not provided)
     * useHttps             does connection use HTTPS?
     * allowSelfSignedCerts are self-signed certificates allow
     * @param busTopicParams contains attributes needed
     * @throws IllegalArgumentException if invalid arguments are detected
     */
    public InlineUebTopicSink(BusTopicParams busTopicParams) {
        super(busTopicParams);
    }

    /**
     * Instantiation of internal resources.
     */
    @Override
    public void init() {

        this.publisher = new BusPublisher.CambriaPublisherWrapper(BusTopicParams.builder()
                .servers(this.servers)
                .topic(this.topic)
                .apiKey(this.apiKey)
                .apiSecret(this.apiSecret)
                .useHttps(this.useHttps)
                .allowSelfSignedCerts(this.allowSelfSignedCerts)
                .build());
        logger.info("{}: UEB SINK created", this);
    }

    @Override
    public String toString() {
        StringBuilder builder = new StringBuilder();
        builder.append("InlineUebTopicSink [getTopicCommInfrastructure()=").append(getTopicCommInfrastructure())
                .append(", toString()=").append(super.toString()).append("]");
        return builder.toString();
    }

    @Override
    public CommInfrastructure getTopicCommInfrastructure() {
        return Topic.CommInfrastructure.UEB;
    }
}
